==> application-blocks-security-1.2-sources.jar: org/genesys/blocks/security/component/Slf4jLogAuditLogger.java <==
/*
 * Copyright 2017 Global Crop Diversity Trust
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.genesys.blocks.security.component;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.security.acls.domain.AuditLogger;
import org.springframework.security.acls.model.AccessControlEntry;
import org.springframework.security.acls.model.AuditableAccessControlEntry;

public class Slf4jLogAuditLogger implements AuditLogger {

	private static final Logger LOG = LoggerFactory.getLogger(Slf4jLogAuditLogger.class);

	@Override
	public void logIfNeeded(boolean granted, AccessControlEntry ace) {
		if (ace != null && ace instanceof AuditableAccessControlEntry) {
			final AuditableAccessControlEntry auditableAce = (AuditableAccessControlEntry) ace;

			if (granted && auditableAce.isAuditSuccess()) {
				LOG.debug("GRANTED due to ACE: " + ace);
			} else if (!granted && auditableAce.isAuditFailure()) {
				LOG.debug("DENIED due to ACE: " + ace);
			}
		}
	}
}

==> application-blocks-security-1.3.1-sources.jar: org/genesys/blocks/security/component/Slf4jLogAuditLogger.java <==
/*
 * Copyright 2017 Global Crop Diversity Trust
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.genesys.blocks.security.component;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.security.acls.domain.AuditLogger;
import org.springframework.security.acls.model.AccessControlEntry;
import org.springframework.security.acls.model.AuditableAccessControlEntry;

/**
 * The Class Slf4jLogAuditLogger.
 */
public class Slf4jLogAuditLogger implements AuditLogger {

	/** The Constant LOG. */
	private static final Logger LOG = LoggerFactory.getLogger(Slf4jLogAuditLogger.class);

	/*
	 * (non-Javadoc)
	 * @see
	 * org.springframework.security.acls.domain.AuditLogger#logIfNeeded(boolean,
	 * org.springframework.security.acls.model.AccessControlEntry)
	 */
	@Override
	public void logIfNeeded(final boolean granted, final AccessControlEntry ace) {
		if ((ace != null) && (ace instanceof AuditableAccessControlEntry)) {
			final AuditableAccessControlEntry auditableAce = (AuditableAccessControlEntry) ace;

			if (granted && auditableAce.isAuditSuccess()) {
				LOG.debug("GRANTED due to ACE: " + ace);
			} else if (!granted && auditableAce.isAuditFailure()) {
				LOG.debug("DENIED due to ACE: " + ace);
			}
		}
	}
}
